summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/kfile_torrent.h
diff options
context:
space:
mode:
Diffstat (limited to 'kfile-plugins/torrent/kfile_torrent.h')
-rw-r--r--kfile-plugins/torrent/kfile_torrent.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kfile-plugins/torrent/kfile_torrent.h b/kfile-plugins/torrent/kfile_torrent.h
index c4ed73fc..203e2b55 100644
--- a/kfile-plugins/torrent/kfile_torrent.h
+++ b/kfile-plugins/torrent/kfile_torrent.h
@@ -38,16 +38,17 @@ class TQStringList;
class KTorrentPlugin : public KFilePlugin
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs the class, and prepares for reading info on a torrent.
*
* @param parent the parent of this object
* @param name the name of this object (not user-readable)
* @param args unused by this class
*/
- KTorrentPlugin (TQObject *parent, const char *name, const TQStringList &args);
+ KTorrentPlugin (TQObject *tqparent, const char *name, const TQStringList &args);
/**
* Destructor that closes the dictionary holding the torrent information.
@@ -38,16 +38,17 @@ class TQStringList;
* Constructs the class, and prepares for reading info on a torrent.
*
- * @param parent the parent of this object
+ * @param tqparent the tqparent of this object
* @param name the name of this object (not user-readable)
* @param args unused by this class